@@ -153,7 +153,7 @@ void Request::setAccessToken(const QString &token) {
     
     if (token != d->accessToken) {
         d->accessToken = token;
-        emit accessTokenChanged();
+        emit accessTokenChanged(token);
     }
 #ifdef QYOUTUBE_DEBUG
     qDebug() << "QYouTube::Request::setAccessToken" << token;
@@ -180,7 +180,7 @@ void Request::setRefreshToken(const QString &token) {
     
     if (token != d->refreshToken) {
         d->refreshToken = token;
-        emit refreshTokenChanged();
+        emit refreshTokenChanged(token);
     }
 #ifdef QYOUTUBE_DEBUG
     qDebug() << "QYouTube::Request::setRefreshToken" << token;
@@ -609,11 +609,6 @@ void Request::post(bool authRequired) {
         return;
     }
     
-    if (d->data.isNull()) {
-        qDebug() << "QYouTube::Request::post(): data is empty";
-        return;
-    }
-    
     d->redirects = 0;
     d->setOperation(PostOperation);
     
@@ -627,10 +622,12 @@ void Request::post(bool authRequired) {
     switch (d->data.type()) {
     case QVariant::String:
     case QVariant::ByteArray:
+    case QVariant::Invalid:
         data = d->data.toByteArray();
         break;
     default:
         data = QtJson::Json::serialize(d->data, ok);
+        break;
     }
 #ifdef QYOUTUBE_DEBUG
     qDebug() << "QYouTube::Request::post" << d->url << data;
@@ -659,11 +656,6 @@ void Request::put(bool authRequired) {
         return;
     }
     
-    if (d->data.isNull()) {
-        qDebug() << "QYouTube::Request::put(): data is empty";
-        return;
-    }
-    
     d->redirects = 0;
     d->setOperation(PutOperation);
     
@@ -677,10 +669,12 @@ void Request::put(bool authRequired) {
     switch (d->data.type()) {
     case QVariant::String:
     case QVariant::ByteArray:
+    case QVariant::Invalid:
         data = d->data.toByteArray();
         break;
     default:
         data = QtJson::Json::serialize(d->data, ok);
+        break;
     }
 #ifdef QYOUTUBE_DEBUG
     qDebug() << "QYouTube::Request::put" << d->url << data;
@@ -773,7 +767,7 @@ void RequestPrivate::setStatus(Request::Status s) {
     if (s != status) {
         Q_Q(Request);
         status = s;
-        emit q->statusChanged();
+        emit q->statusChanged(s);
     }
 #ifdef QYOUTUBE_DEBUG
     qDebug() << "QYouTube::RequestPrivate::setStatus" << Request::Status(s);
@@ -902,7 +896,12 @@ void RequestPrivate::_q_onAccessTokenRefreshed() {
     bool ok;
     setResult(QtJson::Json::parse(reply->readAll(), ok));
     
-    switch (reply->error()) {
+    QNetworkReply::NetworkError e = reply->error();
+    QString es = reply->errorString();
+    reply->deleteLater();
+    reply = 0;
+    
+    switch (e) {
     case QNetworkReply::NoError:
         break;
     case QNetworkReply::OperationCanceledError:
@@ -913,12 +912,12 @@ void RequestPrivate::_q_onAccessTokenRefreshed() {
         return;
     default:
         setStatus(Request::Failed);
-        setError(Request::Error(reply->error()));
-        setErrorString(reply->errorString());
+        setError(Request::Error(e));
+        setErrorString(es);
         emit q->finished();
         return;
     }
-    
+        
     if (ok) {
         QString token = result.toMap().value("access_token").toString();
         
@@ -972,7 +971,10 @@ void RequestPrivate::_q_onReplyFinished() {
         }
     
         if (!redirect.isEmpty()) {
+            reply->deleteLater();
+            reply = 0;
             followRedirect(redirect);
+            return;
         }
     }
     
@@ -980,7 +982,12 @@ void RequestPrivate::_q_onReplyFinished() {
     QString response(reply->readAll());
     setResult(response.isEmpty() ? response : QtJson::Json::parse(response, ok));
     
-    switch (reply->error()) {
+    QNetworkReply::NetworkError e = reply->error();
+    QString es = reply->errorString();
+    reply->deleteLater();
+    reply = 0;
+    
+    switch (e) {
     case QNetworkReply::NoError:
         break;
     case QNetworkReply::OperationCanceledError:
@@ -992,8 +999,8 @@ void RequestPrivate::_q_onReplyFinished() {
     case QNetworkReply::AuthenticationRequiredError:
         if (refreshToken.isEmpty()) {
             setStatus(Request::Failed);
-            setError(Request::Error(reply->error()));
-            setErrorString(reply->errorString());
+            setError(Request::Error(e));
+            setErrorString(es);
             emit q->finished();
         }
         else {
@@ -1003,8 +1010,8 @@ void RequestPrivate::_q_onReplyFinished() {
         return;
     default:
         setStatus(Request::Failed);
-        setError(Request::Error(reply->error()));
-        setErrorString(reply->errorString());
+        setError(Request::Error(e));
+        setErrorString(es);
         emit q->finished();
         return;
     }
@@ -1019,7 +1026,7 @@ void RequestPrivate::_q_onReplyFinished() {
         setError(Request::ParseError);
         setErrorString(Request::tr("Unable to parse response"));
     }
-    
+        
     emit q->finished();
 }
 
